@@ -65,11 +65,11 @@ Web::MREST::Test - Test helper functions
 
 =head1 VERSION
 
-Version 0.268
+Version 0.270
 
 =cut
 
-our $VERSION = '0.268';
+our $VERSION = '0.270';
 
 
 
@@ -144,7 +144,7 @@ sub initialize_unit {
     is( $status->level, 'OK' );
 
     note( 'check that site configuration parameters were loaded' );
-    is_deeply(  $site->MREST_SUPPORTED_CONTENT_TYPES, [ 'application/json' ],
+    is_deeply( [ $site->MREST_SUPPORTED_CONTENT_TYPES ], [ [ 'application/json' ] ],
         'configuration parameters loaded?' );
 
     # set debug mode
